function nrrdWriter(A,header,filename,metric)

%NRRD0004
%# Complete NRRD file format specification at:
%# http://teem.sourceforge.net/nrrd/format.html
%type: float
%dimension: 2, 3 o 4
%space: left-posterior, left-posterior-superior o left-posterior-superior-time
%sizes: 11 20 10
%space directions: (1,0,0) (0,1,0) (0,0,1)
%centerings: cell cell cell
%kinds: space space space
%endian: little
%encoding: raw
%space origin: (0,0,0)
%ITK_InputFilterName:=NRRDExtractPhase
%modality:=Scalar


% Example of header:
%                type: 'short'
%           dimension: '4'
%               space: 'posterior-left-superior-time'
%               sizes: [4x1 double]
%     spacedirections: [4x4 double]
%          centerings: 'cell cell cell cell'
%               kinds: 'space space space time'
%              endian: 'little'
%            encoding: 'raw'
%         spaceorigin: [4x1 double]
%            modality: 'Scalar'




% Por defecto asumimos que la metrica esta en mm
if(~exist('metric','var'))
	metric='mm';
end

dims=size(A);
N=length(dims);


% No estamos modificando el spcadirection. en el nrrdRead
% if(N>3)
%     sp = sscanf(header.spacedirections,'(%f,%f,%f,%f) (%f,%f,%f,%f) (%f,%f,%f,%f) (%f,%f,%f,%f)');
%     x = sp(1:4); y = sp(5:8);  z =sp(9:12); t=sp(13:16);
%     esp = [x y z t];
% elseif(N==3)
%     if(header.spacedimension == 2) % 2D Vector type
%     else
%         sp = sscanf(header.spacedirections,'(%f,%f,%f) (%f,%f,%f) (%f,%f,%f)');
%         x = sp(1:3); y = sp(4:6); z =sp(7:9);
%         esp = [x y z];
%     end
% else
%     N = 2;
%     sp = sscanf(header.spacedirections,'(%f,%f) (%f,%f)');
%     x = sp(1:2); y = sp(3:4);
%     esp = [x y];
% end


% Escalamos el espacioado dependiendo de la metrica utilizada 
switch(metric)
  case 'cm'
  	esp = esp.*10;
end


% Extract the information from the header
% The space direction in convention x-y-z-t



spacedims = N;
if(isfield(header, 'spacedimension'))
    spacedims = header.spacedimension;
end



%Permute dimensions of size and spacing to comply with x-y convention
if(N>=3)
    if(spacedims == 2) % 2D Vector type
        dims = dims([3 2 1]);
        orig = header.spaceorigin([2 1]);
        A = permute(A,[3 2 1]);
    else
        dims = dims([2 1 3:N]);
        orig = header.spaceorigin([2 1 3:N]);
        A = permute(A,[2 1 3:N]);
    end
else
    dims = dims([2 1]);
    orig = header.spaceorigin([2 1]);
    A = permute(A,[2 1]);
end



%Permuta dimensiones de la imagen

%Escribe la cabecera del nrrd
fid=fopen(filename,'w');
fwrite(fid,sprintf('NRRD0004\n'));
fwrite(fid,sprintf('# Complete NRRD file format specification at:\n'));
fwrite(fid,sprintf('# http://teem.sourceforge.net/nrrd/format.html\n'));
% fwrite(fid,sprintf('content: exists(MyNrrd.raw,0)\n'));
fwrite(fid,sprintf('type: %s\n',header.type));
fwrite(fid,sprintf('dimension: %d\n',header.dimension));
if spacedims==3
    fwrite(fid,sprintf('space: left-posterior-superior\n'));
elseif spacedims==4
    fwrite(fid,sprintf('space: left-posterior-superior-time\n'));
elseif spacedims==2
    fwrite(fid,sprintf('space dimension: %d\n',spacedims));
else
    fclose(fid);
    error('Dimension not supported!')
end
fwrite(fid,'sizes:');
for n=1:N
    fwrite(fid,sprintf(' %d',dims(n)));
end
fwrite(fid,sprintf('\n'));
fwrite(fid,sprintf('space directions: %s\n',header.spacedirections));

% fwrite(fid,header.spacedirections);

% if(N == 3 && spacedims == 2)
%     fwrite(fid,'none ');
% end
% 
% for i=1:spacedims
%     if(spacedims>3)
%         v = esp(:,i);
%         fwrite(fid,' (');
%         for j=1:length(v)
%             if(i == spacedims)
%                 fwrite(fid,sprintf('%f)',v(j)));
%             else
%                 fwrite(fid,sprintf('%f,',v(j)));
%             end
%         end
%     elseif spacedims==3
%         fwrite(fid,sprintf(' (%f,%f,%f)',esp(:,i)));
%     else
%         fwrite(fid,sprintf(' (%f,%f)',esp(:,i)));
%     end
% end


% fwrite(fid,sprintf('\n'));
if(spacedims == N)
    fwrite(fid,'centerings:');
    for n=1:N
        fwrite(fid,' cell');
    end
    fwrite(fid,sprintf('\n'));
end

fwrite(fid,sprintf('kinds: %s\n',header.kinds));

% 
% if N>3
%     for n=1:3
%         fwrite(fid,' space');
%     end
%     for n=4:N
%         fwrite(fid,' time');
%     end
% else
%     for n=1:N
%         fwrite(fid,' space');
%     end
% end
% fwrite(fid,sprintf('\n'));
fwrite(fid,sprintf('endian: little\n'));
fwrite(fid,sprintf('encoding: raw\n'));
ORIGIN = int16(orig);
fwrite(fid,'space origin: (');
fprintf(fid,'%d,',ORIGIN(1:end-1));
fprintf(fid,'%d)\n',ORIGIN(end));

if(spacedims == N)
 fwrite(fid,sprintf('modality:=Scalar\n'));
end

fwrite(fid,sprintf('\n'));
fwrite(fid,A,header.type);
fclose(fid);
